<?php
/**
 * Title: Option initializer
 *
 * Description: Initializes theme option. Adds all required files for it.
 *
 * Please do not edit this file. This file is part of the CyberChimps Framework and all modifications
 * should be made in a child theme.
 *
 * @category CyberChimps Framework
 * @package  Framework
 * @since    1.0
 * @author   CyberChimps
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v3.0 (or later)
 * @link     http://www.cyberchimps.com/
 */

/* If the user can't edit theme options, no use running this plugin */
add_action( 'init', 'cyberchimps_edit_themes_role_check' );
function cyberchimps_edit_themes_role_check() {
	if( current_user_can( 'edit_theme_options' ) ) {
		// If the user can edit theme options, let the fun begin!
		add_action( 'admin_init', 'cyberchimps_admin_init' );
	}
}

function cyberchimps_load_styles() {

	// Set template directory uri
	$directory_uri = get_template_directory_uri();

	wp_enqueue_style( 'bootstrap', $directory_uri . '/cyberchimps/lib/bootstrap/css/bootstrap.css' );
	wp_enqueue_style( 'cyberchimps-responsive', $directory_uri . '/cyberchimps/lib/bootstrap/css/cyberchimps-responsive.css', 'bootstrap' );
	wp_enqueue_style( 'plugin_option_styles', $directory_uri . '/cyberchimps/options/lib/css/options-style.css', 'bootstrap');

	wp_enqueue_style( 'color-picker', $directory_uri . '/cyberchimps/options/lib/css/colorpicker.css' );
	wp_enqueue_style( 'thickbox' );
}

function cyberchimps_load_scripts() {

	// Set template directory uri
	$directory_uri = get_template_directory_uri();

	wp_enqueue_media();
	wp_enqueue_script( 'theme-option-media-uploader-3.5', $directory_uri . '/cyberchimps/options/lib/js/media-uploader-new.min.js', array( 'jquery' ) );

	// Enqueued scripts
	wp_enqueue_script( 'jquery-ui-core' );
	wp_enqueue_script( 'jquery-ui-sortable' );

	// Adding JS to support drag and drop in theme options
	wp_enqueue_script( 'jquery-touch-punch-min', $directory_uri . '/cyberchimps/lib/js/touch-punch.min.js', array( 'jquery' ) );
	wp_enqueue_script( 'jquery-touch-sense', $directory_uri . '/cyberchimps/lib/js/touch-sensitive.min.js', array( 'jquery' ) );

	wp_enqueue_script( 'thickbox' );
	wp_enqueue_script( 'color-picker', $directory_uri . '/cyberchimps/options/lib/js/colorpicker.min.js', array( 'jquery' ), '', true );
	wp_enqueue_script( 'media-uploader', $directory_uri . '/cyberchimps/options/lib/js/options-medialibrary-uploader.min.js', array( 'jquery' ), '', true );
	wp_enqueue_script( 'options-custom', $directory_uri . '/cyberchimps/options/lib/js/options-custom.min.js', array( 'jquery' ), '', true );
	wp_enqueue_script( 'bootstrap-js', $directory_uri . '/cyberchimps/lib/bootstrap/js/bootstrap.min.js', array( 'jquery' ), '', true );
	wp_enqueue_script( 'google-fonts', $directory_uri . '/cyberchimps/options/lib/js/font_inline_plugin.min.js', array( 'jquery' ), '', true );
}

// Load options customizer file
add_action( 'init', 'cyberchimps_load_customizer' );
function cyberchimps_load_customizer() {
	require_once dirname( __FILE__ ) . '/options-customizer.php';
}

// add core and theme settings to options page
add_action( 'admin_init', 'cyberchimps_admin_init' );
function cyberchimps_admin_init() {

	// Load options media uploader
	require_once dirname( __FILE__ ) . '/options-medialibrary-uploader.php';

	// register theme options settings
	register_setting( 'cyberchimps_options', 'cyberchimps_options', 'cyberchimps_options_validate' );

}

function cyberchimps_load_options_customizer_new($hook)
{
    wp_enqueue_script( 'option-customizer-new', get_template_directory_uri() . '/cyberchimps/options/lib/js/options-new.js', array( 'jquery' ), '', true);
}
add_action( 'admin_enqueue_scripts', 'cyberchimps_load_options_customizer_new' );
